;; Generated package description from doric-themes.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "doric-themes" "0.5.0" "Highly legible minimalist themes with precise typography" '((emacs "29.1")) :commit "1455871b4fc20b9b4e579681c339f05aa3e9e150" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :keywords '("faces" "theme" "accessibility") :url "https://github.com/protesilaos/doric-themes")
